==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property destination A director and base filename where archive files should be written. See Destination for more details.
 * @property frameCaptureCdnSettings
 */
public data class ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings(
    public val destination:
    ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsDestination,
    public val frameCaptureCdnSettings:
    ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsFrameCaptureCdnSettings? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings):
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings =
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings(
                destination = javaType.destination().let({ args0 ->
                    com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsDestination.Companion.toKotlin(args0)
                }),
                frameCaptureCdnSettings = javaType.frameCaptureCdnSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsFrameCaptureCdnSettings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property destination
 * @property frameCaptureCdnSettings
 */
public data class ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings(
    public val destination: ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsDestination,
    public val frameCaptureCdnSettings: ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsFrameCaptureCdnSettings? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings): ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings =
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettings(
                destination = javaType.destination().let({ args0 ->
                    com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsDestination.Companion.toKotlin(args0)
                }),
                frameCaptureCdnSettings = javaType.frameCaptureCdnSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsFrameCaptureGroupSettingsFrameCaptureCdnSettings.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
